ToastMessage

Enum ToastMessage 

pub enum ToastMessage {
    Show {
        message: String,
        toast_type: ToastType,
        position: ToastPosition,
    },
    Hide,
}
The messages that can be sent to the ToastEngine to control the display of toasts. The Show variant contains the message to display, the type of toast, and its position, while the Hide variant indicates that any currently displayed toast should be hidden.

NOTE: You do have to handle the events yourself. Usually, its as simple as matching on the ToastMessage in your event loop and calling the appropriate methods on the ToastEngine to show or hide toasts based on the received messages.

Variants



Show

Fields

message: String
toast_type: ToastType
position: ToastPosition


Hide